@@ -1,23 +1,8 @@
 /*
+ * Embedded Linux library
+ * Copyright (C) 2018  Intel Corporation
  *
- *  Embedded Linux library
- *
- *  Copyright (C) 2018 Intel Corporation. All rights reserved.
- *
- *  This library is free software; you can redistribute it and/or
- *  modify it under the terms of the GNU Lesser General Public
- *  License as published by the Free Software Foundation; either
- *  version 2.1 of the License, or (at your option) any later version.
- *
- *  This library is distributed in the hope that it will be useful,
- *  but WITHOUT ANY WARRANTY; without even the implied warranty of
- *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- *  Lesser General Public License for more details.
- *
- *  You should have received a copy of the GNU Lesser General Public
- *  License along with this library; if not, write to the Free Software
- *  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
- *
+ * SPDX-License-Identifier: LGPL-2.1-or-later
  */
 
 #ifdef HAVE_CONFIG_H
@@ -218,7 +203,7 @@ static void run_test_p256(const void *arg)
 			scalar[L_ECC_MAX_DIGITS], result[L_ECC_MAX_DIGITS],
 			check[L_ECC_MAX_DIGITS];
 	struct l_ecc_point point1, point2, point_ret;
-	const struct l_ecc_curve *curve = l_ecc_curve_get_ike_group(19);
+	const struct l_ecc_curve *curve = l_ecc_curve_from_ike_group(19);
 
 	point_ret.curve = curve;
 
@@ -317,6 +302,115 @@ static void run_test_p256(const void *arg)
 	}
 }
 
+static void run_test_reduce(const void *arg)
+{
+	static const uint8_t p_reduced[] = {
+		0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
+		0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
+		0x43, 0x19, 0x05, 0x53, 0x58, 0xe8, 0x61, 0x7b,
+		0x0c, 0x46, 0x35, 0x3d, 0x03, 0x9c, 0xda, 0xb0,
+	};
+
+	const struct l_ecc_curve *p256 = l_ecc_curve_from_ike_group(19);
+	struct l_ecc_scalar *tmp;
+	struct l_ecc_scalar *reduced;
+	char buf[32];
+
+	tmp = l_ecc_curve_get_prime(p256);
+	assert(tmp);
+	assert(l_ecc_scalar_get_data(tmp, buf, sizeof(buf)) > 0);
+	l_ecc_scalar_free(tmp);
+
+	reduced = l_ecc_scalar_new_reduced_1_to_n(p256, buf, sizeof(buf));
+	assert(reduced);
+	assert(l_ecc_scalar_get_data(reduced, buf, sizeof(buf)) > 0);
+	assert(!memcmp(buf, p_reduced, sizeof(p_reduced)));
+	l_ecc_scalar_free(reduced);
+
+	tmp = l_ecc_curve_get_order(p256);
+	assert(tmp);
+	assert(l_ecc_scalar_get_data(tmp, buf, sizeof(buf)) > 0);
+	l_ecc_scalar_free(tmp);
+
+	reduced = l_ecc_scalar_new_reduced_1_to_n(p256, buf, sizeof(buf));
+	assert(reduced);
+	assert(l_ecc_scalar_get_data(reduced, buf, sizeof(buf)) > 0);
+	assert(l_memeqzero(buf, 31));
+	assert(buf[31] == 0x02);
+	l_ecc_scalar_free(reduced);
+}
+
+static void run_test_zero_or_one(const void *arg)
+{
+	uint64_t zero[L_ECC_MAX_DIGITS] = { };
+	uint64_t _1[L_ECC_MAX_DIGITS] = { 1ull };
+	uint64_t _2[L_ECC_MAX_DIGITS] = { 2ull };
+
+	assert(_vli_is_zero_or_one(zero, L_ECC_MAX_DIGITS));
+	assert(_vli_is_zero_or_one(_1, L_ECC_MAX_DIGITS));
+	assert(!_vli_is_zero_or_one(_2, L_ECC_MAX_DIGITS));
+}
+
+struct compressed_point_data {
+	char *x;
+	char *exp_y;
+	enum l_ecc_point_type type;
+};
+
+static struct compressed_point_data compressed_tests[] = {
+	{
+		/* BIT0, computed Y is odd, subtraction performed */
+		.x = "19b3fec1c000a888ee9c44272e4d7317e6e36577fc9d53e1edfb4e296b0b7ce1",
+		.exp_y = "a8f9efd0ab526cd930870779621f4e9a53d4e78887ac9f4ed45ff75ded32b158",
+		.type = L_ECC_POINT_TYPE_COMPRESSED_BIT0,
+	},
+	{
+		/* BIT0, computed Y is even, no subtraction */
+		.x = "958df5997362a9695ad73938c86be34a4730da877eccaaf8b189e73ff20e67c3",
+		.exp_y = "1042f37262ded34d8424c1728a1ed23a726645b71db30a38f2932001a2027f46",
+		.type = L_ECC_POINT_TYPE_COMPRESSED_BIT0,
+	},
+	{
+		/* BIT1, computed Y is even, subtraction performed */
+		.x = "069bd56634454ca76e7ba434244137509141cbbf532586c6b36e9b5be8a2cc34",
+		.exp_y = "f4f34d46e4bdc1473fec4b4c8724f349375a8a602f5e83c260d6724e64ec7e99",
+		.type = L_ECC_POINT_TYPE_COMPRESSED_BIT1,
+	},
+	{
+		/* BIT1, computed Y is odd, no subtraction */
+		.x = "8cade296a68e0c40bcf45a049f1993263bdc8524825e2be44b14ce114e475df0",
+		.exp_y = "94ed7d09b2a0e95d8df993eaf81eb64d5ff734d01da57e53b2e0277199bc5897",
+		.type = L_ECC_POINT_TYPE_COMPRESSED_BIT1,
+	},
+};
+
+static void run_test_compressed_points(const void *arg)
+{
+	unsigned int i;
+
+	for (i = 0; i < L_ARRAY_SIZE(compressed_tests); i++) {
+		const struct l_ecc_curve *curve = l_ecc_curve_from_ike_group(19);
+		struct compressed_point_data *data = &compressed_tests[i];
+		uint64_t x[L_ECC_MAX_DIGITS];
+		uint64_t y[L_ECC_MAX_DIGITS];
+		uint64_t exp_y[L_ECC_MAX_DIGITS];
+		size_t bytes = l_ecc_curve_get_scalar_bytes(curve);
+		struct l_ecc_point *p;
+
+		HEX2BUF(data->x, x);
+		HEX2BUF(data->exp_y, exp_y);
+
+		p = l_ecc_point_from_data(curve, data->type, x, bytes);
+		assert(p);
+
+		l_ecc_point_get_y(p, y, bytes);
+
+		assert(!memcmp(exp_y, y, bytes));
+
+		l_ecc_point_free(p);
+	}
+}
+
 int main(int argc, char *argv[])
 {
 	l_test_init(&argc, &argv);
@@ -336,5 +430,9 @@ int main(int argc, char *argv[])
 	l_test_add("ECC legendre", run_test_p256, &legendre_test5);
 	l_test_add("ECC legendre", run_test_p256, &legendre_test6);
 
+	l_test_add("ECC reduce test", run_test_reduce, NULL);
+	l_test_add("ECC zero or one test", run_test_zero_or_one, NULL);
+	l_test_add("ECC compressed points", run_test_compressed_points, NULL);
+
 	return l_test_run();
 }
